package App::sitelenmute;

our $VERSION = 3.04;

=head1 NAME

App::sitelenmute - a static image gallery creator

=head1 DESCRIPTION

This is a stub module, see F<script/sitelen-mute> for details of the app.

=head1 AUTHOR

Alex Schroeder

=head1 LICENSE

GNU General Public License, Version 3

=cut

1;
