/* noscript environment, based on https://css-tricks.com/seamless-responsive-photo-grid/ */
html, body
{
  overflow: hidden; /* IE<9 */
  padding: 0;
  margin: 0;
  border: 0;
  height: 100.1% /* IOS>7.1 meta viewport minimal-ui to hide menu + bars */
}

body
{
  overflow: scroll;
  background-color: #eee;
}

#photos {
  /* Prevent vertical gaps */
  line-height: 0;
  -webkit-column-count: 8;
  -webkit-column-gap:   0px;
  -moz-column-count:    8;
  -moz-column-gap:      0px;
  column-count:         8;
  column-gap:           0px;  
}

#photos img {
  /* Just in case there are inline attributes */
  width: 100% !important;
  height: auto !important;
}

@media (max-width: 1200px) {
  #photos {
    -moz-column-count:    7;
    -webkit-column-count: 7;
    column-count:         7;
  }
}

@media (max-width: 1000px) {
  #photos {
    -moz-column-count:    6;
    -webkit-column-count: 6;
    column-count:         6;
  }
}

@media (max-width: 800px) {
  #photos {
    -moz-column-count:    5;
    -webkit-column-count: 5;
    column-count:         5;
  }
}

@media (max-width: 400px) {
  #photos {
    -moz-column-count:    3;
    -webkit-column-count: 3;
    column-count:         3;
  }
}
