body
{
  padding: 0;
  margin: 0;
  border: 0;
  background: #111;
  color: #fff;
}

h2
{
  margin: 1em;
  font-family: monospace;
}

#albums .album
{
  display: block;
  width: 90%;
  margin: 5%;
}

#albums .album .content
{
  position: absolute;
  width: inherit;
  text-align: center;
}

#albums .album .content .imgblock
{
  display: inline-block;
}

#albums .album .text
{
  position: relative;
  text-shadow: 0 0 0.2em #000
}

#albums .album img
{
  border: 2px solid #eee;
}

#albums a, #albums a:active, #albums a:focus
{
  color: inherit;
  text-decoration: none;
  text-align: center;
  outline: none;
}

#photos {
  /* Prevent vertical gaps */
  line-height: 0;
  
  -webkit-column-count: 8;
  -webkit-column-gap:   0px;
  -moz-column-count:    8;
  -moz-column-gap:      0px;
  column-count:         8;
  column-gap:           0px;  
}

#photos img {
  /* Just in case there are inline attributes */
  width: 100% !important;
  height: auto !important;
}

@media (max-width: 1200px) {
  #photos {
  -moz-column-count:    7;
  -webkit-column-count: 7;
  column-count:         7;
  }
}
@media (max-width: 1000px) {
  #photos {
  -moz-column-count:    6;
  -webkit-column-count: 6;
  column-count:         6;
  }
}
@media (max-width: 800px) {
  #photos {
  -moz-column-count:    5;
  -webkit-column-count: 5;
  column-count:         5;
  }
}
@media (max-width: 400px) {
  #photos {
  -moz-column-count:    3;
  -webkit-column-count: 3;
  column-count:         3;
  }
}
